Changelog
---------
0.3.3 (2018-01-18)
~~~~~~~~~~~~~~~~~~~~~

- Fixes handling of whitespace in mini html.
  [msom]

0.3.2 (2018-01-11)
~~~~~~~~~~~~~~~~~~~~~

- Adds support for indentation of lists.
  [msom]

- Fixes handling of whitespace in mini html.
  [msom]

0.3.1 (2018-01-10)
~~~~~~~~~~~~~~~~~~~~~

- Requires Python 3.6.
  [href]

- Adds compatibility with onegov.file.
  [msom]

0.3.0 (2017-11-17)
~~~~~~~~~~~~~~~~~~~~~

- Rewrites the mini_html function to use list flowables and a HTML sanitizer/
  cleaner.
  [msom]

- Adds h4.
  [msom]

0.2.0 (2017-11-14)
~~~~~~~~~~~~~~~~~~~~~

- Adds a generic header and footer.
  [msom]

0.1.1 (2017-11-13)
~~~~~~~~~~~~~~~~~~~~~

- Adds lexwork PDF signer.
  [msom]

0.1.0 (2017-11-13)
~~~~~~~~~~~~~~~~~~~~~

- Initial Release
